@@ -1,11 +1,9 @@
 import argparse
 import os
 import sys
-import logging
 
 import pytest
 import yaml
-from loguru import logger
 
 from aomaker import __version__, __description__, __image__
 from aomaker.scaffold import init_parser_scaffold, main_scaffold
@@ -13,52 +11,80 @@ from aomaker.make import init_make_parser, main_make
 from aomaker.make_testcase import init_make_case_parser, main_make_case, init_case_parser, main_case
 from aomaker.extension.har_parse import init_har2yaml_parser, main_har2yaml
 from aomaker.extension.recording import init_record_parser, main_record
+from aomaker.path import CONF_DIR
+from aomaker._constants import Conf
+from aomaker.log import AoMakerLogger
+from aomaker._log import logger
 
 
 def init_parser_run(subparsers):
     sub_parser_run = subparsers.add_parser(
-        "run", help="Make AOMaker testcases and run with pytest."
+        "run", help="Make testcases and run with aomaker."
     )
     sub_parser_run.add_argument(
-        "-e", "--env", dest="env", help="switch test environment "
+        "-e", "--env", dest="env", help="switch test environment."
+    )
+    sub_parser_run.add_argument(
+        "-l",
+        # "--log-level",
+        dest="level",
+        choices=["trace", "debug", "info", "success", "warning", "error", "critical"],
+        default="debug",
+        help="set log level."
+    )
+
+    group = sub_parser_run.add_argument_group("multi-run")
+    group.add_argument(
+        "--mp",
+        "--multi-process",
+        dest="mp",
+        action="store_true",
+        help="specifies a multi-process running mode."
+    )
+    group.add_argument(
+        "--mt",
+        "--multi-thread",
+        dest="mt",
+        action="store_true",
+        help="specifies a multi-thread running mode."
+    )
+    group.add_argument(
+        "--dist-suite",
+        dest="dist_suite",
+        help="specifies a dist mode for per worker."
+    )
+    group.add_argument(
+        "--dist-file",
+        dest="dist_file",
+        help="specifies a dist mode for per worker."
+    )
+    group.add_argument(
+        "--dist-mark",
+        dest="dist_mark",
+        # 将传入参数值放到一个list中且至少需要传入一个值
+        nargs="+",
+        help="specifies a dist mode for per worker."
     )
     return sub_parser_run
 
 
 def set_conf_file(env):
-    if os.path.exists('conf/config.yaml'):
-        with open('conf/config.yaml') as f:
+    conf_path = os.path.join(CONF_DIR, Conf.CONF_NAME)
+    if os.path.exists(conf_path):
+        with open(conf_path) as f:
             doc = yaml.safe_load(f)
         doc['env'] = env
         if not doc.get(env):
             logger.error(f'测试环境-{env}还未在配置文件中配置！')
             sys.exit(1)
-        with open('conf/config.yaml', 'w') as f:
+        with open(conf_path, 'w') as f:
             yaml.safe_dump(doc, f, default_flow_style=False)
-        logger.info(f'Current Test Env: {env}')
+        print(f'<AoMaker> 当前测试环境: {env}')
     else:
-        logger.error('配置文件conf/config.yaml不存在')
+        logger.error(f'配置文件{conf_path}不存在')
         sys.exit(1)
 
 
-def main_run(extra_args):
-    # attachment log into allure report
-    class PropogateHandler(logging.Handler):
-        def emit(self, record):
-            logging.getLogger(record.name).handle(record)
-
-    logger.add(PropogateHandler(), format="| {time:YYYY-MM-DD HH:mm:ss} | {message}")
-    logger.info("start to run")
-    # if "--pytest-tmreport-name=report/test_report.html" not in extra_args:
-    #     extra_args.append("--pytest-tmreport-path=report/")
-    #     extra_args.append("--pytest-tmreport-name=test_report.html")
-    extra_args.append("--html=report/aomaker_report.html")
-    extra_args.append("--self-contained-html")
-    extra_args.append("--capture=sys")
-    logger.info(f"start to run tests with pytest. AOMaker version: {__version__}")
-    return pytest.main(extra_args)
-
-
 def main():
     """Parse command line options and run commands.
     """
@@ -116,11 +142,11 @@ def main():
             sys.exit(0)
         elif sys.argv[1] == "run" and sys.argv[2] == "-e":
             # aomaker run -e xxx
-            print('please input env name in "conf/config.yaml"')
+            logger.error('please input env name in "conf/config.yaml"')
             sys.exit(0)
         elif sys.argv[1] == "make" and sys.argv[2] == "-t":
             # aomaker make -s xxx
-            print('please input file path(YAML or Swagger)')
+            logger.error('please input file path(YAML or Swagger)')
             # print('please input template:"qingcloud" or "restful".default template style:restful')
             sys.exit(0)
     # elif sys.argv[1] == "run" and sys.argv[2] == "-e":
@@ -130,11 +156,11 @@ def main():
     #
     #     set_conf_file(sys.argv[3])
     elif sys.argv[1] == "make" and sys.argv[2] == "-t" and sys.argv[3] not in ["qingcloud", "restful"]:
-        print('please input template style:qingcloud or restful')
+        logger.error('please input template style:qingcloud or restful')
         sys.exit(0)
     elif sys.argv[1] == "har2y":
         if not sys.argv[-1].endswith('.yaml') or sys.argv[-1].endswith('.har'):
-            print("please input YAML/HAR file path.")
+            logger.error("please input YAML/HAR file path.")
             sys.exit(1)
 
     extra_args = []
@@ -147,27 +173,62 @@ def main():
         sys.exit(0)
 
     if sys.argv[1] == "startproject":
+        print(__image__)
         main_scaffold(args)
-        print('Project created successfully!')
+        logger.info('项目脚手架创建完成')
     elif sys.argv[1] == "make":
+        print(__image__)
         if sys.argv[2] == '-t' and sys.argv[3] == 'qingcloud':
             main_make(args.file_path, template=args.template)
         else:
             main_make(args.file_path)
-        print('API object generated successfully!')
+        logger.info('api object渲染完成')
     elif sys.argv[1] == "case":
+        print(__image__)
         main_case(args.file_path)
+        logger.info('用例脚本编写完成')
     elif sys.argv[1] == "mcase":
+        print(__image__)
         main_make_case(args.file_path)
-        print('Test cases generated successfully from test data!')
+        logger.info('测试用例生成完成')
     elif sys.argv[1] == "har2y":
+        print(__image__)
         main_har2yaml(args)
+        logger.info('har转换yaml完成')
     elif sys.argv[1] == "record":
+        print(__image__)
         main_record(args)
+        logger.info('用例录制完成')
     elif sys.argv[1] == "run":
+        print(__image__)
         if sys.argv[2] == "-e":
-            set_conf_file(sys.argv[3])
-        sys.exit(main_run(extra_args))
+            set_conf_file(args.env)
+        # if "--log-level" in sys.argv or "-l" in sys.argv:
+        if "-l" in sys.argv:
+            AoMakerLogger.change_level(args.level)
+        from aomaker.runner import run, threads_run, processes_run
+        if args.mp:
+            login_obj = _handle_login()
+            # 多进程
+            if "--dist-mark" in sys.argv:
+                mark_list = [f"-m {mark}" for mark in args.dist_mark]
+                sys.exit(processes_run(mark_list, login=login_obj, extra_args=extra_args))
+            elif "--dist-suite" in sys.argv:
+                sys.exit(processes_run(args.dist_suite, login=login_obj, extra_args=extra_args))
+            elif "--dist-file" in sys.argv:
+                sys.exit(processes_run({"path": args.dist_file}, login=login_obj, extra_args=extra_args))
+        if args.mt:
+            login_obj = _handle_login()
+            # 多线程
+            if "--dist-mark" in sys.argv:
+                mark_list = [f"-m {mark}" for mark in args.dist_mark]
+                sys.exit(threads_run(mark_list, login=login_obj, extra_args=extra_args))
+            elif "--dist-suite" in sys.argv:
+                sys.exit(threads_run(args.dist_suite, login=login_obj, extra_args=extra_args))
+            elif "--dist-file" in sys.argv:
+                sys.exit(threads_run({"path": args.dist_file}, login=login_obj, extra_args=extra_args))
+        login_obj = _handle_login()
+        sys.exit(run(extra_args, login=login_obj))
 
 
 def main_arun_alias():
@@ -205,5 +266,12 @@ def main_record_alias():
     main()
 
 
+def _handle_login():
+    sys.path.append(os.getcwd())
+    exec('from login import Login')
+    login_obj = locals()['Login']()
+    return login_obj
+
+
 if __name__ == '__main__':
     main()
